(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Times New Roman", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Times New Roman", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Times New Roman", 14, L0, center, nohscroll, italic;
	fontset = section, "Times New Roman", 18, L0, nohscroll, bold, grayBox;
	fontset = subsection, "Times New Roman", 14, L0, nohscroll, bold, blackBox;
	fontset = subsubsection, "Times New Roman", 12, L0, nohscroll, bold, whiteBox;
	fontset = text, "Times New Roman", 12, L0, nohscroll;
	fontset = smalltext, "Times New Roman", 10, L0, nohscroll;
	fontset = input, "Courier New", 12, L-5, nowordwrap, bold;
	fontset = output, "Courier New", 8, L-5, nowordwrap;
	fontset = message, "Courier New", 12, L-5, nowordwrap, R65280;
	fontset = print, "Courier New", 12, L-5, nowordwrap;
	fontset = info, "Courier New", 12, L-5, nowordwrap, B65280;
	fontset = postscript, "Courier New", 12, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic;
	fontset = header, "Times New Roman", 12, L0;
	fontset = footer, "Times New Roman", 12, L0, center;
	fontset = help, "Times New Roman", 10, L0, nohscroll;
	fontset = clipboard, "Times New Roman", 12, L0, nohscroll;
	fontset = completions, "Times New Roman", 12, L0, nohscroll;
	fontset = graphics, "Courier New", 9, L0, nowordwrap, nohscroll;
	fontset = special1, "Times New Roman", 12, L0, nohscroll;
	fontset = special2, "Times New Roman", 12, L0, nohscroll;
	fontset = special3, "Times New Roman", 12, L0, nohscroll;
	fontset = special4, "Times New Roman", 12, L0, nohscroll;
	fontset = special5, "Times New Roman", 12, L0, nohscroll;
	fontset = leftheader, "Times New Roman", 12, L0;
	fontset = leftfooter, "Times New Roman", 12, L0;
	fontset = reserved1, "Courier New", 9, L0, nowordwrap, nohscroll;]
:[font = title; inactive; preserveAspect; nohscroll; center; ]
Bifurcation Diagram 
of the 
Logistic Map
:[font = text; inactive; preserveAspect; nohscroll; ]
Il file  modificato rispetto a quello standard distribuito con Mathematica
:[font = section; inactive; preserveAspect; startGroup; Cclosed; nohscroll; ]
Discussion and Implementation
:[font = text; inactive; preserveAspect; nohscroll; ]
The parametrized family of functions given by
:[font = input; preserveAspect; nowordwrap; ]
f[c_, x_] := c x (1-x)
:[font = text; inactive; preserveAspect; nohscroll; backColorRed65280; backColorGreen65280; backColorBlue65280; fontColorRed0; fontColorGreen0; fontColorBlue0; plain; fontName = "Times New Roman"; fontSize = 12; ]
is called the logistic or quadratic family.  For each fixed c between 0 and 4, a member of the quadratic family maps the interval between 0 and 1 into itself.  Here are plots of f[c,x] for 
c = 1, 2, 3, and 4.
:[font = input; preserveAspect; nowordwrap; ]
Plot[Evaluate[Table[f[c, x], {c, 0, 4}]], 
		{x, 0, 1}]
:[font = text; inactive; preserveAspect; nohscroll; ]
Starting with a point x between 0 and 1, we compute f[c, x].  Since f[c, x] is also between 0 and 1, we can compute f[c, f[c,x]], and so on.  This process is called iteration and can be expressed very succinctly using the Mathematica  function NestList. Let's fix c = 3 and compute the first 20 iterations of the point x = .5.
:[font = input; preserveAspect; nowordwrap; ]
 g[x_] := f[3, x]
:[font = input; preserveAspect; startGroup; nowordwrap; ]
 l=NestList[g, .5, 20]
:[font = input; endGroup; nowordwrap; backColorRed65280; backColorGreen65280; backColorBlue65280; fontColorRed0; fontColorGreen0; fontColorBlue0; bold; fontName = "Courier New"; fontSize = 12; ]
ListPlot[l]
:[font = input; nowordwrap; ]
ListPlot[l,PlotJoined->True]
:[font = text; inactive; preserveAspect; nohscroll; ]
Notice that this seems to be settling into a repetitive pattern of period 2. Let's increase the value of c a little. 
:[font = input; preserveAspect; nowordwrap; ]
g[x_] := f[3.5, x]
:[font = input; preserveAspect; startGroup; nowordwrap; ]
ll=NestList[g, .5, 20]
:[font = input; endGroup; nowordwrap; backColorRed65280; backColorGreen65280; backColorBlue65280; fontColorRed0; fontColorGreen0; fontColorBlue0; bold; fontName = "Courier New"; fontSize = 12; ]
ListPlot[ll,PlotRange->{0,1}]
:[font = text; inactive; preserveAspect; nohscroll; ]
Now we get a repeating pattern of period 4. If c were increased again we would see period 8, and then period 16, etc. This process is called period doubling and culminates at the Feigenbaum Point (about c = 3.5699456718...). 
:[font = text; inactive; preserveAspect; nohscroll; ]
Our method for changing c above was rather awkward. An elegant way to examine the behavior as c changes is to use  FoldList to simultaneously iterate and sweep the parameter. 
:[font = input; preserveAspect; nowordwrap; ]
logistic[n_Integer] :=
 Module[ {f, t, x},
	f = Compile[{x, t}, 
		Evaluate[(3 + t/n) x (1 - x)]];
	FoldList[f, 0.223, Range[n]]]
:[font = input; startGroup; nowordwrap; ]
ListPlot[logistic[8000],
                 PlotStyle->PointSize[0.001]]
:[font = output; inactive; formatted; output; endGroup; nowordwrap; ]
No Input Form was saved for this expression.





;[o]
-Graphics-
:[font = text; inactive; preserveAspect; endGroup; nohscroll; ]
The next input cell produces a sound cell. You can clearly hear the period doubling route to chaos. Note also that there is a period three window in a  parameter interval to the right of the Feigenbaum point. It has recently been proved that such stable windows (with various periods) occur densely in the parameter values.
:[font = input; preserveAspect; startGroup; Cclosed; nowordwrap; backColorRed65280; backColorGreen65280; backColorBlue65280; fontColorRed0; fontColorGreen0; fontColorBlue0; bold; fontName = "Courier New"; fontSize = 12; ]
ListPlay[logistic[8000]];
:[font = text; inactive; preserveAspect; nohscroll; backColorRed65280; backColorGreen65280; backColorBlue65280; fontColorRed0; fontColorGreen0; fontColorBlue0; plain; fontName = "Times New Roman"; fontSize = 12; ]
Double-click the top of the next cell bracket (the speaker-shaped icon)  to play a sound once. Note that to play sounds in Mathematica your computer must be equipped with a sound card (e.g., SOUNDBLASTER) and either Multimedia Extensions for Windows 3.0, or Windows 3.1.
:[font = smalltext; inactive; endGroup; nohscroll; backColorRed65280; backColorGreen65280; backColorBlue65280; fontColorRed0; fontColorGreen0; fontColorBlue0; plain; fontName = "Times New Roman"; fontSize = 10; ]
Copyright 1991-93 Wolfram Research, Inc.
^*)